==> peperit_2.0_estable.zip: themes/peperit/html_files/cookies.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Politica de cookies
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");

// Incluimos la miga
//escupirMiga("Cookies");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Cookies', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">

                <p><?= traducir('Esta Política de Cookies es complemento de la Política de Privacidad del sitio web %-Shop::$configuracion->url-% (en adelante, el “Sitio Web”) titularidad de %-Shop::$empresa->nombre_legal-%. El acceso y la navegación por el Sitio Web, o el uso de los servicios del mismo, implican la aceptación de lo establecido en Aviso Legal del Sitio Web y de su Política de Privacidad.'); ?></p>

                <p><?= traducir('Con el fin de facilitar la navegación por el Sitio Web, %-Shop::$empresa->nombre_legal-%, con domicilio social en la %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-% %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%), con NIF %-Shop::$empresa->cif-%, le comunica que utiliza cookies u otros archivos de funcionalidad similar (en adelante, las “Cookies”).'); ?></p>

                <h3><?= traducir('¿Qué es una cookie?'); ?></h3>

                <p><?= traducir('Las Cookies son archivos que contienen pequeñas cantidades de información que se descargan en el dispositivo del usuario cuando visita una página web. Su finalidad principal es reconocer al usuario cada vez que accede al Sitio Web permitiendo, además, mejorar la calidad y ofrecer un mejor uso de Sitio Web.'); ?></p>

                <p><?= traducir('Las Cookies son esenciales para el funcionamiento de Internet, ya que ayudan, entre otras funciones, a identificar y resolver posibles errores de funcionamiento del Sitio Web.'); ?></p>

                <h3><?= traducir('Uso de Cookies por parte de %-Shop::$empresa->nombre_legal-%'); ?></h3>

                <p><?= traducir('El acceso al Sitio Web supone la aceptación expresa de la utilización de las Cookies detalladas en la presente Política en aquellos dispositivos utilizados para realizar dicho acceso. Si se desactivan las Cookies, puede que el uso del Sitio Web no sea óptimo y algunas de las utilidades de que dispone el Sitio Web no funcionen correctamente.'); ?></p>

                <p><?= traducir('Concretamente, %-Shop::$empresa->nombre_legal-% está utilizando las Cookies para la identificación de aquellos usuarios que aceptan el uso de cookies por parte del Sitio Web y permitir la instalación de las mimas,')?><?= traducir(' permitir el log-in de los usuarios en aquellos casos en los que éste sea necesario para acceder a determinadas secciones de Sitio Web, así como recordar los datos de log-in de dichos usuarios en futuras visitas y poder ofrecer así una experiencia de navegación más cómoda, así como evaluar el uso del Sitio Web y la actividad del mismo.'); ?></p>

                <p><?= traducir('Asimismo, las Cookies ayudan protegen a los usuarios de posibles ataques que puedan recibir de terceros.'); ?></p>

                <h3><?= traducir('Cookies propias'); ?></h3>
                <p><?= traducir('Cookies técnicas y de personalización:'); ?></p>
                <p><?= traducir('Estas Cookies facilitan el acceso y navegación del usuario por el Sitio Web en cada una de sus visitas al mismo y la utilización de las diferentes opciones o servicios que existen como, por ejemplo, el idioma predeterminado que el usuario utiliza en el Sitio Web. '); ?></p>
                <p><?= traducir(' Utilizamos cookies propias estrictamente necesarias para la autenticación de usuario, mantenimiento de la sesión, datos del carrito y datos de la compra por internet.'); ?></p>
    
                <div class="volver">
                  
                </div> 
            </article>
        </div>
    </div>
</section>

==> peperit_2.1_estable.zip: themes/peperit/html_files/cookies.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 12/Enero/2015
// Version 1.0 Politica de cookies
//---------------------------------------------------------------------------------------------------------
?>
<?php
include("comunes/globals.php");

// Incluimos la miga
//escupirMiga("Cookies");
?>
<div class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <?php
    escupirMiga('Cookies', FALSE, '>');
    ?>
</div>
<section class="<?=Theme::getConfigParam('container_style', 'container');?>">
    <div class="row">
        <div class="col-md-12">
            <article id="textos_legales">

                <p><?= traducir('Esta Política de Cookies es complemento de la Política de Privacidad del sitio web %-Shop::$configuracion->url-% (en adelante, el “Sitio Web”) titularidad de %-Shop::$empresa->nombre_legal-%, en adelante %-Shop::$empresa->nombre-%. El acceso y la navegación por el Sitio Web, o el uso de los servicios del mismo, implican la aceptación de lo establecido en Aviso Legal del Sitio Web y de su Política de Privacidad.'); ?></p>

                <p><?= traducir('Con el fin de facilitar la navegación por el Sitio Web, %-Shop::$empresa->nombre-%, con domicilio social en la %-Shop::$empresa->direccion-%; %-Shop::$empresa->cod_postal-% %-Shop::$empresa->localidad-% (%-Shop::$empresa->provincia-%), con NIF %-Shop::$empresa->cif-%, le comunica que utiliza cookies u otros archivos de funcionalidad similar (en adelante, las “Cookies”).'); ?></p>

                <h3><?= traducir('¿Qué es una cookie?'); ?></h3>

                <p><?= traducir('Las Cookies son archivos que contienen pequeñas cantidades de información que se descargan en el dispositivo del usuario cuando visita una página web. Su finalidad principal es reconocer al usuario cada vez que accede al Sitio Web permitiendo, además, mejorar la calidad y ofrecer un mejor uso de Sitio Web.'); ?></p>

                <p><?= traducir('Las Cookies son esenciales para el funcionamiento de Internet, ya que ayudan, entre otras funciones, a identificar y resolver posibles errores de funcionamiento del Sitio Web.'); ?></p>

                <h3><?= traducir('Uso de Cookies por parte de %-Shop::$empresa->nombre-%'); ?></h3>

                <p><?= traducir('El acceso al Sitio Web supone la aceptación expresa de la utilización de las Cookies detalladas en la presente Política en aquellos dispositivos utilizados para realizar dicho acceso. Si se desactivan las Cookies, puede que el uso del Sitio Web no sea óptimo y algunas de las utilidades de que dispone el Sitio Web no funcionen correctamente.'); ?></p>

                <p><?= traducir('Concretamente, %-Shop::$empresa->nombre-% está utilizando las Cookies para la identificación de aquellos usuarios que aceptan el uso de cookies por parte del Sitio Web y permitir la instalación de las mismas,')?><?= traducir(' permitir el log-in de los usuarios en aquellos casos en los que éste sea necesario para acceder a determinadas secciones de Sitio Web, así como recordar los datos de log-in de dichos usuarios en futuras visitas y poder ofrecer así una experiencia de navegación más cómoda, así como evaluar el uso del Sitio Web y la actividad del mismo.'); ?></p>

                <p><?= traducir('Asimismo, las Cookies ayudan protegen a los usuarios de posibles ataques que puedan recibir de terceros.'); ?></p>

                <h3><?= traducir('Cookies propias'); ?></h3>
                <p><?= traducir('Cookies técnicas y de personalización:'); ?></p>
                <p><?= traducir('Estas Cookies facilitan el acceso y navegación del usuario por el Sitio Web en cada una de sus visitas al mismo y la utilización de las diferentes opciones o servicios que existen como, por ejemplo, el idioma predeterminado que el usuario utiliza en el Sitio Web. '); ?></p>
                <p><?= traducir(' Utilizamos cookies propias estrictamente necesarias para la autenticación de usuario, mantenimiento de la sesión, datos del carrito y datos de la compra por internet.'); ?></p>
    
                <div class="volver">
                  
                </div> 
            </article>
        </div>
    </div>
</section>
